// Test case that compares a file generated by rust_xlsxwriter with a file
// created by Excel.
//
// SPDX-License-Identifier: MIT OR Apache-2.0
//
// Copyright 2022-2025, John McNamara, jmcnamara@cpan.org

use crate::common;
use rust_xlsxwriter::{HeaderImagePosition, Image, Workbook, XlsxError};

// Test to demonstrate adding header/footer images to worksheets.
fn create_new_xlsx_file(filename: &str) -> Result<(), XlsxError> {
    let mut workbook = Workbook::new();

    let image = Image::new("tests/input/images/red.jpg")?;

    let worksheet1 = workbook.add_worksheet();
    worksheet1.set_header("&L&G");
    worksheet1.set_header_image(&image, HeaderImagePosition::Left)?;
    worksheet1.set_footer("&R&G");
    worksheet1.set_footer_image(&image, HeaderImagePosition::Right)?;

    let worksheet2 = workbook.add_worksheet();
    worksheet2.set_header("&L&G");
    worksheet2.set_header_image(&image, HeaderImagePosition::Left)?;
    worksheet2.set_footer("&R&G");
    worksheet2.set_footer_image(&image, HeaderImagePosition::Right)?;

    workbook.save(filename)?;

    Ok(())
}

#[test]
fn test_header_image16() {
    let test_runner = common::TestRunner::new()
        .set_name("header_image16")
        .set_function(create_new_xlsx_file)
        .initialize();

    test_runner.assert_eq();
    test_runner.cleanup();
}
