// Test case that compares a file generated by rust_xlsxwriter with a file
// created by Excel.
//
// SPDX-License-Identifier: MIT OR Apache-2.0
//
// Copyright 2022-2025, John McNamara, jmcnamara@cpan.org

use crate::common;
use rust_xlsxwriter::{Image, ObjectMovement, Workbook, XlsxError};

// Test to demonstrate adding images to worksheets.
fn create_new_xlsx_file(filename: &str) -> Result<(), XlsxError> {
    let mut workbook = Workbook::new();

    let worksheet = workbook.add_worksheet();

    let image = Image::new("tests/input/images/red.png")?
        .set_alt_text("red.png")
        .set_object_movement(ObjectMovement::MoveAndSizeWithCellsAfter);

    worksheet.insert_image(8, 4, &image)?;

    worksheet.set_row_height(8, 30)?;
    worksheet.set_row_hidden(8)?;

    workbook.save(filename)?;

    Ok(())
}

#[test]
fn test_image45() {
    let test_runner = common::TestRunner::new()
        .set_name("image45")
        .set_function(create_new_xlsx_file)
        .initialize();

    test_runner.assert_eq();
    test_runner.cleanup();
}
